.. _multi_physics-thermal_electric:

multi_physics/thermal_electric.py
=================================

**Description**


First solve the stationary electric conduction problem. Then use its
results to solve the evolutionary heat conduction problem.

Run this example as on a command line::

    $ python <path_to_this_file>/thermal_electric.py


.. image:: /../doc/images/gallery/multi_physics-thermal_electric.10.png
.. image:: /../doc/images/gallery/multi_physics-thermal_electric.el.png


:download:`source code </../sfepy/examples/multi_physics/thermal_electric.py>`

.. literalinclude:: /../sfepy/examples/multi_physics/thermal_electric.py

